@@ -143,8 +143,8 @@ def _mako_loader_cpp(path, namespace, tags, version, specs, meta):
 validation_files = {
     'valddi.cpp.mako': ('','valddi.cpp'),
     'entry_points.h.mako' : ('common', 'entry_points.h'),
-    'param.cpp.mako' : ('parameter_validation', 'parameter_validation.cpp'),
-    'param.h.mako' : ('parameter_validation', 'parameter_validation.h'),
+    'param.cpp.mako' : ('checkers/parameter_validation', 'parameter_validation.cpp'),
+    'param.h.mako' : ('checkers/parameter_validation', 'parameter_validation.h'),
     'handle_lifetime.h.mako' : ('handle_lifetime_tracking', 'handle_lifetime.h'),
     'handle_lifetime.cpp.mako' : ('handle_lifetime_tracking', 'handle_lifetime.cpp')
 }
