@@ -17,7 +17,9 @@ namespace loader {
 
 static const char *knownDriverNames[] = {
     MAKE_LIBRARY_NAME("ze_intel_gpu", "1"),
+    MAKE_LIBRARY_NAME("ze_intel_gpu_legacy1", "1"),
     MAKE_LIBRARY_NAME("ze_intel_vpu", "1"),
+    MAKE_LIBRARY_NAME("ze_intel_npu", "1"),
 };
 
 std::vector<DriverLibraryPath> discoverEnabledDrivers() {
