@@ -6,7 +6,7 @@
  *
  */
 
-#include "../ze_loader.h"
+#include "../ze_loader_internal.h"
 
 namespace loader
 {
