@@ -30,88 +30,6 @@ namespace loader
         zel_logger->log_trace(message + result);
     };
 
-    std::string to_string(const ze_result_t result) {
-        if (result == ZE_RESULT_SUCCESS) {
-            return "ZE_RESULT_SUCCESS";
-        } else if (result == ZE_RESULT_NOT_READY) {
-            return "ZE_RESULT_NOT_READY";
-        } else if (result == ZE_RESULT_ERROR_UNINITIALIZED) {
-            return "ZE_RESULT_ERROR_UNINITIALIZED";
-        } else if (result == ZE_RESULT_ERROR_DEVICE_LOST) {
-            return "ZE_RESULT_ERROR_DEVICE_LOST";
-        } else if (result == ZE_RESULT_ERROR_INVALID_ARGUMENT) {
-            return "ZE_RESULT_ERROR_INVALID_ARGUMENT";
-        } else if (result == ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY) {
-            return "ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY";
-        } else if (result == ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY) {
-            return "ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY";
-        } else if (result == ZE_RESULT_ERROR_MODULE_BUILD_FAILURE) {
-            return "ZE_RESULT_ERROR_MODULE_BUILD_FAILURE";
-        } else if (result == ZE_RESULT_ERROR_MODULE_LINK_FAILURE) {
-            return "ZE_RESULT_ERROR_MODULE_LINK_FAILURE";
-        } else if (result == ZE_RESULT_ERROR_INSUFFICIENT_PERMISSIONS) {
-            return "ZE_RESULT_ERROR_INSUFFICIENT_PERMISSIONS";
-        } else if (result == ZE_RESULT_ERROR_NOT_AVAILABLE) {
-            return "ZE_RESULT_ERROR_NOT_AVAILABLE";
-        } else if (result == ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE) {
-            return "ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE";
-        } else if (result == ZE_RESULT_WARNING_DROPPED_DATA) {
-            return "ZE_RESULT_WARNING_DROPPED_DATA";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_VERSION) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_VERSION";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_FEATURE) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_FEATURE";
-        } else if (result == ZE_RESULT_ERROR_INVALID_NULL_HANDLE) {
-            return "ZE_RESULT_ERROR_INVALID_NULL_HANDLE";
-        } else if (result == ZE_RESULT_ERROR_HANDLE_OBJECT_IN_USE) {
-            return "ZE_RESULT_ERROR_HANDLE_OBJECT_IN_USE";
-        } else if (result == ZE_RESULT_ERROR_INVALID_NULL_POINTER) {
-            return "ZE_RESULT_ERROR_INVALID_NULL_POINTER";
-        } else if (result == ZE_RESULT_ERROR_INVALID_SIZE) {
-            return "ZE_RESULT_ERROR_INVALID_SIZE";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_SIZE) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_SIZE";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_ALIGNMENT) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_ALIGNMENT";
-        } else if (result == ZE_RESULT_ERROR_INVALID_SYNCHRONIZATION_OBJECT) {
-            return "ZE_RESULT_ERROR_INVALID_SYNCHRONIZATION_OBJECT";
-        } else if (result == ZE_RESULT_ERROR_INVALID_ENUMERATION) {
-            return "ZE_RESULT_ERROR_INVALID_ENUMERATION";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_ENUMERATION) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_ENUMERATION";
-        } else if (result == ZE_RESULT_ERROR_UNSUPPORTED_IMAGE_FORMAT) {
-            return "ZE_RESULT_ERROR_UNSUPPORTED_IMAGE_FORMAT";
-        } else if (result == ZE_RESULT_ERROR_INVALID_NATIVE_BINARY) {
-            return "ZE_RESULT_ERROR_INVALID_NATIVE_BINARY";
-        } else if (result == ZE_RESULT_ERROR_INVALID_GLOBAL_NAME) {
-            return "ZE_RESULT_ERROR_INVALID_GLOBAL_NAME";
-        } else if (result == ZE_RESULT_ERROR_INVALID_KERNEL_NAME) {
-            return "ZE_RESULT_ERROR_INVALID_KERNEL_NAME";
-        } else if (result == ZE_RESULT_ERROR_INVALID_FUNCTION_NAME) {
-            return "ZE_RESULT_ERROR_INVALID_FUNCTION_NAME";
-        } else if (result == ZE_RESULT_ERROR_INVALID_GROUP_SIZE_DIMENSION) {
-            return "ZE_RESULT_ERROR_INVALID_GROUP_SIZE_DIMENSION";
-        } else if (result == ZE_RESULT_ERROR_INVALID_GLOBAL_WIDTH_DIMENSION) {
-            return "ZE_RESULT_ERROR_INVALID_GLOBAL_WIDTH_DIMENSION";
-        } else if (result == ZE_RESULT_ERROR_INVALID_KERNEL_ARGUMENT_INDEX) {
-            return "ZE_RESULT_ERROR_INVALID_KERNEL_ARGUMENT_INDEX";
-        } else if (result == ZE_RESULT_ERROR_INVALID_KERNEL_ARGUMENT_SIZE) {
-            return "ZE_RESULT_ERROR_INVALID_KERNEL_ARGUMENT_SIZE";
-        } else if (result == ZE_RESULT_ERROR_INVALID_KERNEL_ATTRIBUTE_VALUE) {
-            return "ZE_RESULT_ERROR_INVALID_KERNEL_ATTRIBUTE_VALUE";
-        } else if (result == ZE_RESULT_ERROR_INVALID_MODULE_UNLINKED) {
-            return "ZE_RESULT_ERROR_INVALID_MODULE_UNLINKED";
-        } else if (result == ZE_RESULT_ERROR_INVALID_COMMAND_LIST_TYPE) {
-            return "ZE_RESULT_ERROR_INVALID_COMMAND_LIST_TYPE";
-        } else if (result == ZE_RESULT_ERROR_OVERLAPPING_REGIONS) {
-            return "ZE_RESULT_ERROR_OVERLAPPING_REGIONS";
-        } else if (result == ZE_RESULT_ERROR_UNKNOWN) {
-            return "ZE_RESULT_ERROR_UNKNOWN";
-        } else {
-            return std::to_string(static_cast<int>(result));
-        }
-    }
-
     std::string to_string(const ze_init_flags_t flags) {
         if (flags & ZE_INIT_FLAG_GPU_ONLY) {
             return "ZE_INIT_FLAG_GPU_ONLY";
@@ -318,10 +236,11 @@ namespace loader
                 // Use the previously init ddi table pointer to zeInit to allow for intercept of the zeInit calls
                 ze_result_t res = globalInitStored->pfnInit(flags);
                 // Verify that this driver successfully init in the call above.
-                if (driver.initStatus != ZE_RESULT_SUCCESS) {
-                    res = driver.initStatus;
+                if (res != ZE_RESULT_SUCCESS || driver.initStatus != ZE_RESULT_SUCCESS) {
+                    if (driver.initStatus != ZE_RESULT_SUCCESS)
+                        res = driver.initStatus;
                     if (debugTraceEnabled) {
-                        std::string message = "init driver " + driver.name + " zeInit(" + loader::to_string(flags) + ") returning ";
+                        std::string message = "init driver (global ddi) " + driver.name + " zeInit(" + loader::to_string(flags) + ") returning ";
                         debug_trace_message(message, loader::to_string(res));
                     }
                     return res;
@@ -359,10 +278,11 @@ namespace loader
                 // Use the previously init ddi table pointer to zeInit to allow for intercept of the zeInit calls
                 ze_result_t res = globalInitStored->pfnInitDrivers(&pCount, nullptr, desc);
                 // Verify that this driver successfully init in the call above.
-                if (driver.initDriversStatus != ZE_RESULT_SUCCESS) {
-                    res = driver.initDriversStatus;
+                if (res != ZE_RESULT_SUCCESS || driver.initDriversStatus != ZE_RESULT_SUCCESS) {
+                    if (driver.initDriversStatus != ZE_RESULT_SUCCESS)
+                        res = driver.initDriversStatus;
                     if (debugTraceEnabled) {
-                        std::string message = "init driver " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
+                        std::string message = "init driver (global ddi) " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
                         debug_trace_message(message, loader::to_string(res));
                     }
                     return res;
@@ -374,7 +294,7 @@ namespace loader
                 // Verify that this driver successfully init in the call above.
                 if (res != ZE_RESULT_SUCCESS) {
                     if (debugTraceEnabled) {
-                        std::string message = "init driver " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
+                        std::string message = "init driver (driver ddi) " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
                         debug_trace_message(message, loader::to_string(res));
                     }
                     return res;
@@ -385,7 +305,7 @@ namespace loader
                 // Verify that this driver successfully init in the call above.
                 if (res != ZE_RESULT_SUCCESS) {
                     if (debugTraceEnabled) {
-                        std::string message = "init driver " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
+                        std::string message = "init driver (driver ddi) " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
                         debug_trace_message(message, loader::to_string(res));
                     }
                     return res;
@@ -393,7 +313,9 @@ namespace loader
             }
 
             for (auto handle : driverHandles) {
-                ze_driver_properties_t properties;
+                ze_driver_properties_t properties = {};
+                properties.stype = ZE_STRUCTURE_TYPE_DRIVER_PROPERTIES;
+                properties.pNext = nullptr;
                 ze_result_t res = driver.dditable.ze.Driver.pfnGetProperties(handle, &properties);
                 if (res != ZE_RESULT_SUCCESS) {
                     if (debugTraceEnabled) {
@@ -432,7 +354,9 @@ namespace loader
                 bool discreteGPU = false;
                 bool other = false;
                 for( auto device : deviceHandles ) {
-                    ze_device_properties_t deviceProperties;
+                    ze_device_properties_t deviceProperties = {};
+                    deviceProperties.stype = ZE_STRUCTURE_TYPE_DEVICE_PROPERTIES;
+                    deviceProperties.pNext = nullptr;
                     res = driver.dditable.ze.Device.pfnGetProperties(device, &deviceProperties);
                     if( ZE_RESULT_SUCCESS != res ) {
                         if (debugTraceEnabled) {
@@ -477,58 +401,13 @@ namespace loader
         auto discoveredDrivers = discoverEnabledDrivers();
         std::string loadLibraryErrorValue;
 
-        auto log_directory = getenv_string("ZEL_LOADER_LOG_DIR");
-        if (log_directory.empty()) {
-            std::string home_dir;
-#ifdef _WIN32
-            home_dir = getenv_string("USERPROFILE");
-            if (home_dir == ""){
-                auto home_drive = getenv_string("HOMEDRIVE");
-                auto home_path = getenv_string("HOMEPATH");
-                if ((home_drive != "") && (home_path != "")) {
-                    home_dir = home_drive + home_path;
-                } else {
-                    home_dir = ".";
-                }
-            }
-            log_directory = home_dir + "\\" + LOADER_LOG_FILE_DIRECTORY;
-#else
-            home_dir = getenv_string("HOME");
+        zel_logger = createLogger();
 
-            if (home_dir == "") {
-                auto pwdir = getpwuid(getuid())->pw_dir;
-                home_dir = (pwdir == NULL) ? "." : std::string(pwdir);
-            }
-            log_directory = home_dir + "/" + LOADER_LOG_FILE_DIRECTORY;
-#endif
-        }
-        auto loader_file = getenv_string("ZEL_LOADER_LOG_FILE");
-        if (loader_file.empty()){
-            loader_file = LOADER_LOG_FILE;
-        } else {
-            auto log_depr_msg = "ZEL_LOADER_LOG_FILE will be deprecated in a future release";
-            std::cout << log_depr_msg << std::endl;
-        }
-
-        std::string full_log_file_path = "";
-#ifdef _WIN32
-        full_log_file_path = log_directory + "\\" + loader_file;
-#else
-        full_log_file_path = log_directory + "/" + loader_file;
-#endif
-        auto logging_enabled = getenv_tobool( "ZEL_ENABLE_LOADER_LOGGING" );
-
-        auto log_level = getenv_string("ZEL_LOADER_LOGGING_LEVEL");
-        zel_logger =  std::make_shared<Logger>("ze_loader", full_log_file_path, !log_level.empty() ? log_level : "warn", logging_enabled);
-        if ((log_level == "trace") && !debugTraceEnabled) {
+        if ((getenv_string("ZEL_LOADER_LOGGING_LEVEL") == "trace") && !debugTraceEnabled) {
             debugTraceEnabled = true;
             zel_logger->log_to_console = false;
         }
 
-        if (!logging_enabled){
-            zel_logger->set_level(spdlog::level::off);
-        }
-
         if (zel_logger->logging_enabled)
             zel_logger->get_base_logger()->info("Loader Version {}.{}.{} {}", LOADER_VERSION_MAJOR, LOADER_VERSION_MINOR, LOADER_VERSION_PATCH, LOADER_VERSION_SHA);
 
